# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/abci/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper


# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from packages.valory.connections.abci.gogoproto import (
    gogo_pb2 as gogoproto_dot_gogo__pb2,
)
from packages.valory.connections.abci.tendermint.crypto import (
    keys_pb2 as tendermint_dot_crypto_dot_keys__pb2,
)
from packages.valory.connections.abci.tendermint.crypto import (
    proof_pb2 as tendermint_dot_crypto_dot_proof__pb2,
)
from packages.valory.connections.abci.tendermint.types import (
    params_pb2 as tendermint_dot_types_dot_params__pb2,
)
from packages.valory.connections.abci.tendermint.types import (
    types_pb2 as tendermint_dot_types_dot_types__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="tendermint/abci/types.proto",
    package="tendermint.abci",
    syntax="proto3",
    serialized_options=b"Z+github.com/tendermint/tendermint/abci/types",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\x1btendermint/abci/types.proto\x12\x0ftendermint.abci\x1a\x1dtendermint/crypto/proof.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ctendermint/crypto/keys.proto\x1a\x1dtendermint/types/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto"\xea\x06\n\x07Request\x12,\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.RequestEchoH\x00\x12.\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.RequestFlushH\x00\x12,\n\x04info\x18\x03 \x01(\x0b\x32\x1c.tendermint.abci.RequestInfoH\x00\x12\x37\n\nset_option\x18\x04 \x01(\x0b\x32!.tendermint.abci.RequestSetOptionH\x00\x12\x37\n\ninit_chain\x18\x05 \x01(\x0b\x32!.tendermint.abci.RequestInitChainH\x00\x12.\n\x05query\x18\x06 \x01(\x0b\x32\x1d.tendermint.abci.RequestQueryH\x00\x12\x39\n\x0b\x62\x65gin_block\x18\x07 \x01(\x0b\x32".tendermint.abci.RequestBeginBlockH\x00\x12\x33\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32\x1f.tendermint.abci.RequestCheckTxH\x00\x12\x37\n\ndeliver_tx\x18\t \x01(\x0b\x32!.tendermint.abci.RequestDeliverTxH\x00\x12\x35\n\tend_block\x18\n \x01(\x0b\x32 .tendermint.abci.RequestEndBlockH\x00\x12\x30\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1e.tendermint.abci.RequestCommitH\x00\x12?\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32%.tendermint.abci.RequestListSnapshotsH\x00\x12?\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32%.tendermint.abci.RequestOfferSnapshotH\x00\x12H\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32).tendermint.abci.RequestLoadSnapshotChunkH\x00\x12J\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.RequestApplySnapshotChunkH\x00\x42\x07\n\x05value"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t"\x0e\n\x0cRequestFlush"J\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04".\n\x10RequestSetOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"\x81\x02\n\x10RequestInitChain\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12:\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x04 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03"I\n\x0cRequestQuery\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08"\xd1\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12.\n\x06header\x18\x02 \x01(\x0b\x32\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12?\n\x10last_commit_info\x18\x03 \x01(\x0b\x32\x1f.tendermint.abci.LastCommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\x19.tendermint.abci.EvidenceB\x04\xc8\xde\x1f\x00"H\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12*\n\x04type\x18\x02 \x01(\x0e\x32\x1c.tendermint.abci.CheckTxType"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c"!\n\x0fRequestEndBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03"\x0f\n\rRequestCommit"\x16\n\x14RequestListSnapshots"U\n\x14RequestOfferSnapshot\x12+\n\x08snapshot\x18\x01 \x01(\x0b\x32\x19.tendermint.abci.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c"I\n\x18RequestLoadSnapshotChunk\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r"I\n\x19RequestApplySnapshotChunk\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t"\xb3\x07\n\x08Response\x12\x37\n\texception\x18\x01 \x01(\x0b\x32".tendermint.abci.ResponseExceptionH\x00\x12-\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1d.tendermint.abci.ResponseEchoH\x00\x12/\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1e.tendermint.abci.ResponseFlushH\x00\x12-\n\x04info\x18\x04 \x01(\x0b\x32\x1d.tendermint.abci.ResponseInfoH\x00\x12\x38\n\nset_option\x18\x05 \x01(\x0b\x32".tendermint.abci.ResponseSetOptionH\x00\x12\x38\n\ninit_chain\x18\x06 \x01(\x0b\x32".tendermint.abci.ResponseInitChainH\x00\x12/\n\x05query\x18\x07 \x01(\x0b\x32\x1e.tendermint.abci.ResponseQueryH\x00\x12:\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlockH\x00\x12\x34\n\x08\x63heck_tx\x18\t \x01(\x0b\x32 .tendermint.abci.ResponseCheckTxH\x00\x12\x38\n\ndeliver_tx\x18\n \x01(\x0b\x32".tendermint.abci.ResponseDeliverTxH\x00\x12\x36\n\tend_block\x18\x0b \x01(\x0b\x32!.tendermint.abci.ResponseEndBlockH\x00\x12\x31\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1f.tendermint.abci.ResponseCommitH\x00\x12@\n\x0elist_snapshots\x18\r \x01(\x0b\x32&.tendermint.abci.ResponseListSnapshotsH\x00\x12@\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32&.tendermint.abci.ResponseOfferSnapshotH\x00\x12I\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32*.tendermint.abci.ResponseLoadSnapshotChunkH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32+.tendermint.abci.ResponseApplySnapshotChunkH\x00\x42\x07\n\x05value""\n\x11ResponseException\x12\r\n\x05\x65rror\x18\x01 \x01(\t"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t"\x0f\n\rResponseFlush"z\n\x0cResponseInfo\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c"<\n\x11ResponseSetOption\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t"\x9d\x01\n\x11ResponseInitChain\x12:\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x02 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c"\xb6\x01\n\rResponseQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12.\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1b.tendermint.crypto.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t"V\n\x12ResponseBeginBlock\x12@\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty"\xd9\x01\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t"\xdb\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t"\xda\x01\n\x10ResponseEndBlock\x12\x41\n\x11validator_updates\x18\x01 \x03(\x0b\x32 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x41\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32 .tendermint.abci.ConsensusParams\x12@\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty"5\n\x0eResponseCommit\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x15\n\rretain_height\x18\x03 \x01(\x03"E\n\x15ResponseListSnapshots\x12,\n\tsnapshots\x18\x01 \x03(\x0b\x32\x19.tendermint.abci.Snapshot"\xb6\x01\n\x15ResponseOfferSnapshot\x12=\n\x06result\x18\x01 \x01(\x0e\x32-.tendermint.abci.ResponseOfferSnapshot.Result"^\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\n\n\x06REJECT\x10\x03\x12\x11\n\rREJECT_FORMAT\x10\x04\x12\x11\n\rREJECT_SENDER\x10\x05"*\n\x19ResponseLoadSnapshotChunk\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c"\xf2\x01\n\x1aResponseApplySnapshotChunk\x12\x42\n\x06result\x18\x01 \x01(\x0e\x32\x32.tendermint.abci.ResponseApplySnapshotChunk.Result\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t"`\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43\x43\x45PT\x10\x01\x12\t\n\x05\x41\x42ORT\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x12\n\x0eRETRY_SNAPSHOT\x10\x04\x12\x13\n\x0fREJECT_SNAPSHOT\x10\x05"\xda\x01\n\x0f\x43onsensusParams\x12+\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1c.tendermint.abci.BlockParams\x12\x32\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParams\x12\x34\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParams\x12\x30\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParams"1\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03"O\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12.\n\x05votes\x18\x02 \x03(\x0b\x32\x19.tendermint.abci.VoteInfoB\x04\xc8\xde\x1f\x00"h\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Q\n\nattributes\x18\x02 \x03(\x0b\x32\x1f.tendermint.abci.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x08"o\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x38\n\x06result\x18\x04 \x01(\x0b\x32".tendermint.abci.ResponseDeliverTxB\x04\xc8\xde\x1f\x00"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03"U\n\x0fValidatorUpdate\x12\x33\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\r\n\x05power\x18\x02 \x01(\x03"Z\n\x08VoteInfo\x12\x33\n\tvalidator\x18\x01 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x19\n\x11signed_last_block\x18\x02 \x01(\x08"\xcc\x01\n\x08\x45vidence\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.tendermint.abci.EvidenceType\x12\x33\n\tvalidator\x18\x02 \x01(\x0b\x32\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*9\n\x0b\x43heckTxType\x12\x10\n\x03NEW\x10\x00\x1a\x07\x8a\x9d \x03New\x12\x18\n\x07RECHECK\x10\x01\x1a\x0b\x8a\x9d \x07Recheck*H\n\x0c\x45videnceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x44UPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x02\x32\x83\n\n\x0f\x41\x42\x43IApplication\x12\x43\n\x04\x45\x63ho\x12\x1c.tendermint.abci.RequestEcho\x1a\x1d.tendermint.abci.ResponseEcho\x12\x46\n\x05\x46lush\x12\x1d.tendermint.abci.RequestFlush\x1a\x1e.tendermint.abci.ResponseFlush\x12\x43\n\x04Info\x12\x1c.tendermint.abci.RequestInfo\x1a\x1d.tendermint.abci.ResponseInfo\x12R\n\tSetOption\x12!.tendermint.abci.RequestSetOption\x1a".tendermint.abci.ResponseSetOption\x12R\n\tDeliverTx\x12!.tendermint.abci.RequestDeliverTx\x1a".tendermint.abci.ResponseDeliverTx\x12L\n\x07\x43heckTx\x12\x1f.tendermint.abci.RequestCheckTx\x1a .tendermint.abci.ResponseCheckTx\x12\x46\n\x05Query\x12\x1d.tendermint.abci.RequestQuery\x1a\x1e.tendermint.abci.ResponseQuery\x12I\n\x06\x43ommit\x12\x1e.tendermint.abci.RequestCommit\x1a\x1f.tendermint.abci.ResponseCommit\x12R\n\tInitChain\x12!.tendermint.abci.RequestInitChain\x1a".tendermint.abci.ResponseInitChain\x12U\n\nBeginBlock\x12".tendermint.abci.RequestBeginBlock\x1a#.tendermint.abci.ResponseBeginBlock\x12O\n\x08\x45ndBlock\x12 .tendermint.abci.RequestEndBlock\x1a!.tendermint.abci.ResponseEndBlock\x12^\n\rListSnapshots\x12%.tendermint.abci.RequestListSnapshots\x1a&.tendermint.abci.ResponseListSnapshots\x12^\n\rOfferSnapshot\x12%.tendermint.abci.RequestOfferSnapshot\x1a&.tendermint.abci.ResponseOfferSnapshot\x12j\n\x11LoadSnapshotChunk\x12).tendermint.abci.RequestLoadSnapshotChunk\x1a*.tendermint.abci.ResponseLoadSnapshotChunk\x12m\n\x12\x41pplySnapshotChunk\x12*.tendermint.abci.RequestApplySnapshotChunk\x1a+.tendermint.abci.ResponseApplySnapshotChunkB-Z+github.com/tendermint/tendermint/abci/typesb\x06proto3',
    dependencies=[
        tendermint_dot_crypto_dot_proof__pb2.DESCRIPTOR,
        tendermint_dot_types_dot_types__pb2.DESCRIPTOR,
        tendermint_dot_crypto_dot_keys__pb2.DESCRIPTOR,
        tendermint_dot_types_dot_params__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        gogoproto_dot_gogo__pb2.DESCRIPTOR,
    ],
)

_CHECKTXTYPE = _descriptor.EnumDescriptor(
    name="CheckTxType",
    full_name="tendermint.abci.CheckTxType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NEW",
            index=0,
            number=0,
            serialized_options=b"\212\235 \003New",
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RECHECK",
            index=1,
            number=1,
            serialized_options=b"\212\235 \007Recheck",
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6314,
    serialized_end=6371,
)
_sym_db.RegisterEnumDescriptor(_CHECKTXTYPE)

CheckTxType = enum_type_wrapper.EnumTypeWrapper(_CHECKTXTYPE)
_EVIDENCETYPE = _descriptor.EnumDescriptor(
    name="EvidenceType",
    full_name="tendermint.abci.EvidenceType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DUPLICATE_VOTE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="LIGHT_CLIENT_ATTACK",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=6373,
    serialized_end=6445,
)
_sym_db.RegisterEnumDescriptor(_EVIDENCETYPE)

EvidenceType = enum_type_wrapper.EnumTypeWrapper(_EVIDENCETYPE)
NEW = 0
RECHECK = 1
UNKNOWN = 0
DUPLICATE_VOTE = 1
LIGHT_CLIENT_ATTACK = 2


_RESPONSEOFFERSNAPSHOT_RESULT = _descriptor.EnumDescriptor(
    name="Result",
    full_name="tendermint.abci.ResponseOfferSnapshot.Result",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACCEPT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ABORT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REJECT",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REJECT_FORMAT",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REJECT_SENDER",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=4773,
    serialized_end=4867,
)
_sym_db.RegisterEnumDescriptor(_RESPONSEOFFERSNAPSHOT_RESULT)

_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT = _descriptor.EnumDescriptor(
    name="Result",
    full_name="tendermint.abci.ResponseApplySnapshotChunk.Result",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACCEPT",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ABORT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RETRY",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RETRY_SNAPSHOT",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="REJECT_SNAPSHOT",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=5060,
    serialized_end=5156,
)
_sym_db.RegisterEnumDescriptor(_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT)


_REQUEST = _descriptor.Descriptor(
    name="Request",
    full_name="tendermint.abci.Request",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="tendermint.abci.Request.echo",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="flush",
            full_name="tendermint.abci.Request.flush",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.Request.info",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="set_option",
            full_name="tendermint.abci.Request.set_option",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="init_chain",
            full_name="tendermint.abci.Request.init_chain",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="tendermint.abci.Request.query",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="begin_block",
            full_name="tendermint.abci.Request.begin_block",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="check_tx",
            full_name="tendermint.abci.Request.check_tx",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="deliver_tx",
            full_name="tendermint.abci.Request.deliver_tx",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_block",
            full_name="tendermint.abci.Request.end_block",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="commit",
            full_name="tendermint.abci.Request.commit",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="list_snapshots",
            full_name="tendermint.abci.Request.list_snapshots",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="offer_snapshot",
            full_name="tendermint.abci.Request.offer_snapshot",
            index=12,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="load_snapshot_chunk",
            full_name="tendermint.abci.Request.load_snapshot_chunk",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="apply_snapshot_chunk",
            full_name="tendermint.abci.Request.apply_snapshot_chunk",
            index=14,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="value",
            full_name="tendermint.abci.Request.value",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=226,
    serialized_end=1100,
)


_REQUESTECHO = _descriptor.Descriptor(
    name="RequestEcho",
    full_name="tendermint.abci.RequestEcho",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message",
            full_name="tendermint.abci.RequestEcho.message",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1102,
    serialized_end=1132,
)


_REQUESTFLUSH = _descriptor.Descriptor(
    name="RequestFlush",
    full_name="tendermint.abci.RequestFlush",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1134,
    serialized_end=1148,
)


_REQUESTINFO = _descriptor.Descriptor(
    name="RequestInfo",
    full_name="tendermint.abci.RequestInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="version",
            full_name="tendermint.abci.RequestInfo.version",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="block_version",
            full_name="tendermint.abci.RequestInfo.block_version",
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="p2p_version",
            full_name="tendermint.abci.RequestInfo.p2p_version",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1150,
    serialized_end=1224,
)


_REQUESTSETOPTION = _descriptor.Descriptor(
    name="RequestSetOption",
    full_name="tendermint.abci.RequestSetOption",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="tendermint.abci.RequestSetOption.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="tendermint.abci.RequestSetOption.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1226,
    serialized_end=1272,
)


_REQUESTINITCHAIN = _descriptor.Descriptor(
    name="RequestInitChain",
    full_name="tendermint.abci.RequestInitChain",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="time",
            full_name="tendermint.abci.RequestInitChain.time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\220\337\037\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="chain_id",
            full_name="tendermint.abci.RequestInitChain.chain_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="consensus_params",
            full_name="tendermint.abci.RequestInitChain.consensus_params",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validators",
            full_name="tendermint.abci.RequestInitChain.validators",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="app_state_bytes",
            full_name="tendermint.abci.RequestInitChain.app_state_bytes",
            index=4,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="initial_height",
            full_name="tendermint.abci.RequestInitChain.initial_height",
            index=5,
            number=6,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1275,
    serialized_end=1532,
)


_REQUESTQUERY = _descriptor.Descriptor(
    name="RequestQuery",
    full_name="tendermint.abci.RequestQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="data",
            full_name="tendermint.abci.RequestQuery.data",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="path",
            full_name="tendermint.abci.RequestQuery.path",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.RequestQuery.height",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="prove",
            full_name="tendermint.abci.RequestQuery.prove",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1534,
    serialized_end=1607,
)


_REQUESTBEGINBLOCK = _descriptor.Descriptor(
    name="RequestBeginBlock",
    full_name="tendermint.abci.RequestBeginBlock",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="hash",
            full_name="tendermint.abci.RequestBeginBlock.hash",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="header",
            full_name="tendermint.abci.RequestBeginBlock.header",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="last_commit_info",
            full_name="tendermint.abci.RequestBeginBlock.last_commit_info",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="byzantine_validators",
            full_name="tendermint.abci.RequestBeginBlock.byzantine_validators",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1610,
    serialized_end=1819,
)


_REQUESTCHECKTX = _descriptor.Descriptor(
    name="RequestCheckTx",
    full_name="tendermint.abci.RequestCheckTx",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="tx",
            full_name="tendermint.abci.RequestCheckTx.tx",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="tendermint.abci.RequestCheckTx.type",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1821,
    serialized_end=1893,
)


_REQUESTDELIVERTX = _descriptor.Descriptor(
    name="RequestDeliverTx",
    full_name="tendermint.abci.RequestDeliverTx",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="tx",
            full_name="tendermint.abci.RequestDeliverTx.tx",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1895,
    serialized_end=1925,
)


_REQUESTENDBLOCK = _descriptor.Descriptor(
    name="RequestEndBlock",
    full_name="tendermint.abci.RequestEndBlock",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.RequestEndBlock.height",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1927,
    serialized_end=1960,
)


_REQUESTCOMMIT = _descriptor.Descriptor(
    name="RequestCommit",
    full_name="tendermint.abci.RequestCommit",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1962,
    serialized_end=1977,
)


_REQUESTLISTSNAPSHOTS = _descriptor.Descriptor(
    name="RequestListSnapshots",
    full_name="tendermint.abci.RequestListSnapshots",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1979,
    serialized_end=2001,
)


_REQUESTOFFERSNAPSHOT = _descriptor.Descriptor(
    name="RequestOfferSnapshot",
    full_name="tendermint.abci.RequestOfferSnapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshot",
            full_name="tendermint.abci.RequestOfferSnapshot.snapshot",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="app_hash",
            full_name="tendermint.abci.RequestOfferSnapshot.app_hash",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2003,
    serialized_end=2088,
)


_REQUESTLOADSNAPSHOTCHUNK = _descriptor.Descriptor(
    name="RequestLoadSnapshotChunk",
    full_name="tendermint.abci.RequestLoadSnapshotChunk",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.RequestLoadSnapshotChunk.height",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="format",
            full_name="tendermint.abci.RequestLoadSnapshotChunk.format",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="chunk",
            full_name="tendermint.abci.RequestLoadSnapshotChunk.chunk",
            index=2,
            number=3,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2090,
    serialized_end=2163,
)


_REQUESTAPPLYSNAPSHOTCHUNK = _descriptor.Descriptor(
    name="RequestApplySnapshotChunk",
    full_name="tendermint.abci.RequestApplySnapshotChunk",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="index",
            full_name="tendermint.abci.RequestApplySnapshotChunk.index",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="chunk",
            full_name="tendermint.abci.RequestApplySnapshotChunk.chunk",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="sender",
            full_name="tendermint.abci.RequestApplySnapshotChunk.sender",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2165,
    serialized_end=2238,
)


_RESPONSE = _descriptor.Descriptor(
    name="Response",
    full_name="tendermint.abci.Response",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="exception",
            full_name="tendermint.abci.Response.exception",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="tendermint.abci.Response.echo",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="flush",
            full_name="tendermint.abci.Response.flush",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.Response.info",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="set_option",
            full_name="tendermint.abci.Response.set_option",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="init_chain",
            full_name="tendermint.abci.Response.init_chain",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="query",
            full_name="tendermint.abci.Response.query",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="begin_block",
            full_name="tendermint.abci.Response.begin_block",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="check_tx",
            full_name="tendermint.abci.Response.check_tx",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="deliver_tx",
            full_name="tendermint.abci.Response.deliver_tx",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_block",
            full_name="tendermint.abci.Response.end_block",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="commit",
            full_name="tendermint.abci.Response.commit",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="list_snapshots",
            full_name="tendermint.abci.Response.list_snapshots",
            index=12,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="offer_snapshot",
            full_name="tendermint.abci.Response.offer_snapshot",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="load_snapshot_chunk",
            full_name="tendermint.abci.Response.load_snapshot_chunk",
            index=14,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="apply_snapshot_chunk",
            full_name="tendermint.abci.Response.apply_snapshot_chunk",
            index=15,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="value",
            full_name="tendermint.abci.Response.value",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=2241,
    serialized_end=3188,
)


_RESPONSEEXCEPTION = _descriptor.Descriptor(
    name="ResponseException",
    full_name="tendermint.abci.ResponseException",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="error",
            full_name="tendermint.abci.ResponseException.error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3190,
    serialized_end=3224,
)


_RESPONSEECHO = _descriptor.Descriptor(
    name="ResponseEcho",
    full_name="tendermint.abci.ResponseEcho",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message",
            full_name="tendermint.abci.ResponseEcho.message",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3226,
    serialized_end=3257,
)


_RESPONSEFLUSH = _descriptor.Descriptor(
    name="ResponseFlush",
    full_name="tendermint.abci.ResponseFlush",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3259,
    serialized_end=3274,
)


_RESPONSEINFO = _descriptor.Descriptor(
    name="ResponseInfo",
    full_name="tendermint.abci.ResponseInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="data",
            full_name="tendermint.abci.ResponseInfo.data",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="tendermint.abci.ResponseInfo.version",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="app_version",
            full_name="tendermint.abci.ResponseInfo.app_version",
            index=2,
            number=3,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="last_block_height",
            full_name="tendermint.abci.ResponseInfo.last_block_height",
            index=3,
            number=4,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="last_block_app_hash",
            full_name="tendermint.abci.ResponseInfo.last_block_app_hash",
            index=4,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3276,
    serialized_end=3398,
)


_RESPONSESETOPTION = _descriptor.Descriptor(
    name="ResponseSetOption",
    full_name="tendermint.abci.ResponseSetOption",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="tendermint.abci.ResponseSetOption.code",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="log",
            full_name="tendermint.abci.ResponseSetOption.log",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.ResponseSetOption.info",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3400,
    serialized_end=3460,
)


_RESPONSEINITCHAIN = _descriptor.Descriptor(
    name="ResponseInitChain",
    full_name="tendermint.abci.ResponseInitChain",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="consensus_params",
            full_name="tendermint.abci.ResponseInitChain.consensus_params",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validators",
            full_name="tendermint.abci.ResponseInitChain.validators",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="app_hash",
            full_name="tendermint.abci.ResponseInitChain.app_hash",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3463,
    serialized_end=3620,
)


_RESPONSEQUERY = _descriptor.Descriptor(
    name="ResponseQuery",
    full_name="tendermint.abci.ResponseQuery",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="tendermint.abci.ResponseQuery.code",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="log",
            full_name="tendermint.abci.ResponseQuery.log",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.ResponseQuery.info",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="index",
            full_name="tendermint.abci.ResponseQuery.index",
            index=3,
            number=5,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="key",
            full_name="tendermint.abci.ResponseQuery.key",
            index=4,
            number=6,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="tendermint.abci.ResponseQuery.value",
            index=5,
            number=7,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="proof_ops",
            full_name="tendermint.abci.ResponseQuery.proof_ops",
            index=6,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.ResponseQuery.height",
            index=7,
            number=9,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="codespace",
            full_name="tendermint.abci.ResponseQuery.codespace",
            index=8,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3623,
    serialized_end=3805,
)


_RESPONSEBEGINBLOCK = _descriptor.Descriptor(
    name="ResponseBeginBlock",
    full_name="tendermint.abci.ResponseBeginBlock",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="events",
            full_name="tendermint.abci.ResponseBeginBlock.events",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\352\336\037\020events,omitempty",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3807,
    serialized_end=3893,
)


_RESPONSECHECKTX = _descriptor.Descriptor(
    name="ResponseCheckTx",
    full_name="tendermint.abci.ResponseCheckTx",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="tendermint.abci.ResponseCheckTx.code",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="tendermint.abci.ResponseCheckTx.data",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="log",
            full_name="tendermint.abci.ResponseCheckTx.log",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.ResponseCheckTx.info",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gas_wanted",
            full_name="tendermint.abci.ResponseCheckTx.gas_wanted",
            index=4,
            number=5,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name="gas_wanted",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gas_used",
            full_name="tendermint.abci.ResponseCheckTx.gas_used",
            index=5,
            number=6,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name="gas_used",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="events",
            full_name="tendermint.abci.ResponseCheckTx.events",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\352\336\037\020events,omitempty",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="codespace",
            full_name="tendermint.abci.ResponseCheckTx.codespace",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3896,
    serialized_end=4113,
)


_RESPONSEDELIVERTX = _descriptor.Descriptor(
    name="ResponseDeliverTx",
    full_name="tendermint.abci.ResponseDeliverTx",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="code",
            full_name="tendermint.abci.ResponseDeliverTx.code",
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data",
            full_name="tendermint.abci.ResponseDeliverTx.data",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="log",
            full_name="tendermint.abci.ResponseDeliverTx.log",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="info",
            full_name="tendermint.abci.ResponseDeliverTx.info",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gas_wanted",
            full_name="tendermint.abci.ResponseDeliverTx.gas_wanted",
            index=4,
            number=5,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name="gas_wanted",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gas_used",
            full_name="tendermint.abci.ResponseDeliverTx.gas_used",
            index=5,
            number=6,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name="gas_used",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="events",
            full_name="tendermint.abci.ResponseDeliverTx.events",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\352\336\037\020events,omitempty",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="codespace",
            full_name="tendermint.abci.ResponseDeliverTx.codespace",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4116,
    serialized_end=4335,
)


_RESPONSEENDBLOCK = _descriptor.Descriptor(
    name="ResponseEndBlock",
    full_name="tendermint.abci.ResponseEndBlock",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="validator_updates",
            full_name="tendermint.abci.ResponseEndBlock.validator_updates",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="consensus_param_updates",
            full_name="tendermint.abci.ResponseEndBlock.consensus_param_updates",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="events",
            full_name="tendermint.abci.ResponseEndBlock.events",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\352\336\037\020events,omitempty",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4338,
    serialized_end=4556,
)


_RESPONSECOMMIT = _descriptor.Descriptor(
    name="ResponseCommit",
    full_name="tendermint.abci.ResponseCommit",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="data",
            full_name="tendermint.abci.ResponseCommit.data",
            index=0,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="retain_height",
            full_name="tendermint.abci.ResponseCommit.retain_height",
            index=1,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4558,
    serialized_end=4611,
)


_RESPONSELISTSNAPSHOTS = _descriptor.Descriptor(
    name="ResponseListSnapshots",
    full_name="tendermint.abci.ResponseListSnapshots",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="snapshots",
            full_name="tendermint.abci.ResponseListSnapshots.snapshots",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4613,
    serialized_end=4682,
)


_RESPONSEOFFERSNAPSHOT = _descriptor.Descriptor(
    name="ResponseOfferSnapshot",
    full_name="tendermint.abci.ResponseOfferSnapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="result",
            full_name="tendermint.abci.ResponseOfferSnapshot.result",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _RESPONSEOFFERSNAPSHOT_RESULT,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4685,
    serialized_end=4867,
)


_RESPONSELOADSNAPSHOTCHUNK = _descriptor.Descriptor(
    name="ResponseLoadSnapshotChunk",
    full_name="tendermint.abci.ResponseLoadSnapshotChunk",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="chunk",
            full_name="tendermint.abci.ResponseLoadSnapshotChunk.chunk",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4869,
    serialized_end=4911,
)


_RESPONSEAPPLYSNAPSHOTCHUNK = _descriptor.Descriptor(
    name="ResponseApplySnapshotChunk",
    full_name="tendermint.abci.ResponseApplySnapshotChunk",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="result",
            full_name="tendermint.abci.ResponseApplySnapshotChunk.result",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="refetch_chunks",
            full_name="tendermint.abci.ResponseApplySnapshotChunk.refetch_chunks",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="reject_senders",
            full_name="tendermint.abci.ResponseApplySnapshotChunk.reject_senders",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4914,
    serialized_end=5156,
)


_CONSENSUSPARAMS = _descriptor.Descriptor(
    name="ConsensusParams",
    full_name="tendermint.abci.ConsensusParams",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="block",
            full_name="tendermint.abci.ConsensusParams.block",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="evidence",
            full_name="tendermint.abci.ConsensusParams.evidence",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validator",
            full_name="tendermint.abci.ConsensusParams.validator",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="tendermint.abci.ConsensusParams.version",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5159,
    serialized_end=5377,
)


_BLOCKPARAMS = _descriptor.Descriptor(
    name="BlockParams",
    full_name="tendermint.abci.BlockParams",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="max_bytes",
            full_name="tendermint.abci.BlockParams.max_bytes",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="max_gas",
            full_name="tendermint.abci.BlockParams.max_gas",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5379,
    serialized_end=5428,
)


_LASTCOMMITINFO = _descriptor.Descriptor(
    name="LastCommitInfo",
    full_name="tendermint.abci.LastCommitInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="round",
            full_name="tendermint.abci.LastCommitInfo.round",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="votes",
            full_name="tendermint.abci.LastCommitInfo.votes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5430,
    serialized_end=5509,
)


_EVENT = _descriptor.Descriptor(
    name="Event",
    full_name="tendermint.abci.Event",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="tendermint.abci.Event.type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attributes",
            full_name="tendermint.abci.Event.attributes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\352\336\037\024attributes,omitempty",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5511,
    serialized_end=5615,
)


_EVENTATTRIBUTE = _descriptor.Descriptor(
    name="EventAttribute",
    full_name="tendermint.abci.EventAttribute",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="tendermint.abci.EventAttribute.key",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="tendermint.abci.EventAttribute.value",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="index",
            full_name="tendermint.abci.EventAttribute.index",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5617,
    serialized_end=5676,
)


_TXRESULT = _descriptor.Descriptor(
    name="TxResult",
    full_name="tendermint.abci.TxResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.TxResult.height",
            index=0,
            number=1,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="index",
            full_name="tendermint.abci.TxResult.index",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="tx",
            full_name="tendermint.abci.TxResult.tx",
            index=2,
            number=3,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="result",
            full_name="tendermint.abci.TxResult.result",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5678,
    serialized_end=5789,
)


_VALIDATOR = _descriptor.Descriptor(
    name="Validator",
    full_name="tendermint.abci.Validator",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="address",
            full_name="tendermint.abci.Validator.address",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="power",
            full_name="tendermint.abci.Validator.power",
            index=1,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5791,
    serialized_end=5834,
)


_VALIDATORUPDATE = _descriptor.Descriptor(
    name="ValidatorUpdate",
    full_name="tendermint.abci.ValidatorUpdate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="pub_key",
            full_name="tendermint.abci.ValidatorUpdate.pub_key",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="power",
            full_name="tendermint.abci.ValidatorUpdate.power",
            index=1,
            number=2,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5836,
    serialized_end=5921,
)


_VOTEINFO = _descriptor.Descriptor(
    name="VoteInfo",
    full_name="tendermint.abci.VoteInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="validator",
            full_name="tendermint.abci.VoteInfo.validator",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="signed_last_block",
            full_name="tendermint.abci.VoteInfo.signed_last_block",
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=5923,
    serialized_end=6013,
)


_EVIDENCE = _descriptor.Descriptor(
    name="Evidence",
    full_name="tendermint.abci.Evidence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="tendermint.abci.Evidence.type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="validator",
            full_name="tendermint.abci.Evidence.validator",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.Evidence.height",
            index=2,
            number=3,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="time",
            full_name="tendermint.abci.Evidence.time",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\310\336\037\000\220\337\037\001",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="total_voting_power",
            full_name="tendermint.abci.Evidence.total_voting_power",
            index=4,
            number=5,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6016,
    serialized_end=6220,
)


_SNAPSHOT = _descriptor.Descriptor(
    name="Snapshot",
    full_name="tendermint.abci.Snapshot",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="height",
            full_name="tendermint.abci.Snapshot.height",
            index=0,
            number=1,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="format",
            full_name="tendermint.abci.Snapshot.format",
            index=1,
            number=2,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="chunks",
            full_name="tendermint.abci.Snapshot.chunks",
            index=2,
            number=3,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="hash",
            full_name="tendermint.abci.Snapshot.hash",
            index=3,
            number=4,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="tendermint.abci.Snapshot.metadata",
            index=4,
            number=5,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=6222,
    serialized_end=6312,
)

_REQUEST.fields_by_name["echo"].message_type = _REQUESTECHO
_REQUEST.fields_by_name["flush"].message_type = _REQUESTFLUSH
_REQUEST.fields_by_name["info"].message_type = _REQUESTINFO
_REQUEST.fields_by_name["set_option"].message_type = _REQUESTSETOPTION
_REQUEST.fields_by_name["init_chain"].message_type = _REQUESTINITCHAIN
_REQUEST.fields_by_name["query"].message_type = _REQUESTQUERY
_REQUEST.fields_by_name["begin_block"].message_type = _REQUESTBEGINBLOCK
_REQUEST.fields_by_name["check_tx"].message_type = _REQUESTCHECKTX
_REQUEST.fields_by_name["deliver_tx"].message_type = _REQUESTDELIVERTX
_REQUEST.fields_by_name["end_block"].message_type = _REQUESTENDBLOCK
_REQUEST.fields_by_name["commit"].message_type = _REQUESTCOMMIT
_REQUEST.fields_by_name["list_snapshots"].message_type = _REQUESTLISTSNAPSHOTS
_REQUEST.fields_by_name["offer_snapshot"].message_type = _REQUESTOFFERSNAPSHOT
_REQUEST.fields_by_name["load_snapshot_chunk"].message_type = _REQUESTLOADSNAPSHOTCHUNK
_REQUEST.fields_by_name[
    "apply_snapshot_chunk"
].message_type = _REQUESTAPPLYSNAPSHOTCHUNK
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["echo"])
_REQUEST.fields_by_name["echo"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["flush"])
_REQUEST.fields_by_name["flush"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["info"])
_REQUEST.fields_by_name["info"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["set_option"])
_REQUEST.fields_by_name["set_option"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["init_chain"])
_REQUEST.fields_by_name["init_chain"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["query"])
_REQUEST.fields_by_name["query"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["begin_block"])
_REQUEST.fields_by_name["begin_block"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["check_tx"])
_REQUEST.fields_by_name["check_tx"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["deliver_tx"])
_REQUEST.fields_by_name["deliver_tx"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["end_block"])
_REQUEST.fields_by_name["end_block"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(_REQUEST.fields_by_name["commit"])
_REQUEST.fields_by_name["commit"].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(
    _REQUEST.fields_by_name["list_snapshots"]
)
_REQUEST.fields_by_name["list_snapshots"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(
    _REQUEST.fields_by_name["offer_snapshot"]
)
_REQUEST.fields_by_name["offer_snapshot"].containing_oneof = _REQUEST.oneofs_by_name[
    "value"
]
_REQUEST.oneofs_by_name["value"].fields.append(
    _REQUEST.fields_by_name["load_snapshot_chunk"]
)
_REQUEST.fields_by_name[
    "load_snapshot_chunk"
].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUEST.oneofs_by_name["value"].fields.append(
    _REQUEST.fields_by_name["apply_snapshot_chunk"]
)
_REQUEST.fields_by_name[
    "apply_snapshot_chunk"
].containing_oneof = _REQUEST.oneofs_by_name["value"]
_REQUESTINITCHAIN.fields_by_name[
    "time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REQUESTINITCHAIN.fields_by_name["consensus_params"].message_type = _CONSENSUSPARAMS
_REQUESTINITCHAIN.fields_by_name["validators"].message_type = _VALIDATORUPDATE
_REQUESTBEGINBLOCK.fields_by_name[
    "header"
].message_type = tendermint_dot_types_dot_types__pb2._HEADER
_REQUESTBEGINBLOCK.fields_by_name["last_commit_info"].message_type = _LASTCOMMITINFO
_REQUESTBEGINBLOCK.fields_by_name["byzantine_validators"].message_type = _EVIDENCE
_REQUESTCHECKTX.fields_by_name["type"].enum_type = _CHECKTXTYPE
_REQUESTOFFERSNAPSHOT.fields_by_name["snapshot"].message_type = _SNAPSHOT
_RESPONSE.fields_by_name["exception"].message_type = _RESPONSEEXCEPTION
_RESPONSE.fields_by_name["echo"].message_type = _RESPONSEECHO
_RESPONSE.fields_by_name["flush"].message_type = _RESPONSEFLUSH
_RESPONSE.fields_by_name["info"].message_type = _RESPONSEINFO
_RESPONSE.fields_by_name["set_option"].message_type = _RESPONSESETOPTION
_RESPONSE.fields_by_name["init_chain"].message_type = _RESPONSEINITCHAIN
_RESPONSE.fields_by_name["query"].message_type = _RESPONSEQUERY
_RESPONSE.fields_by_name["begin_block"].message_type = _RESPONSEBEGINBLOCK
_RESPONSE.fields_by_name["check_tx"].message_type = _RESPONSECHECKTX
_RESPONSE.fields_by_name["deliver_tx"].message_type = _RESPONSEDELIVERTX
_RESPONSE.fields_by_name["end_block"].message_type = _RESPONSEENDBLOCK
_RESPONSE.fields_by_name["commit"].message_type = _RESPONSECOMMIT
_RESPONSE.fields_by_name["list_snapshots"].message_type = _RESPONSELISTSNAPSHOTS
_RESPONSE.fields_by_name["offer_snapshot"].message_type = _RESPONSEOFFERSNAPSHOT
_RESPONSE.fields_by_name[
    "load_snapshot_chunk"
].message_type = _RESPONSELOADSNAPSHOTCHUNK
_RESPONSE.fields_by_name[
    "apply_snapshot_chunk"
].message_type = _RESPONSEAPPLYSNAPSHOTCHUNK
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["exception"])
_RESPONSE.fields_by_name["exception"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["echo"])
_RESPONSE.fields_by_name["echo"].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["flush"])
_RESPONSE.fields_by_name["flush"].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["info"])
_RESPONSE.fields_by_name["info"].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["set_option"])
_RESPONSE.fields_by_name["set_option"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["init_chain"])
_RESPONSE.fields_by_name["init_chain"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["query"])
_RESPONSE.fields_by_name["query"].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["begin_block"])
_RESPONSE.fields_by_name["begin_block"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["check_tx"])
_RESPONSE.fields_by_name["check_tx"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["deliver_tx"])
_RESPONSE.fields_by_name["deliver_tx"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["end_block"])
_RESPONSE.fields_by_name["end_block"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(_RESPONSE.fields_by_name["commit"])
_RESPONSE.fields_by_name["commit"].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(
    _RESPONSE.fields_by_name["list_snapshots"]
)
_RESPONSE.fields_by_name["list_snapshots"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(
    _RESPONSE.fields_by_name["offer_snapshot"]
)
_RESPONSE.fields_by_name["offer_snapshot"].containing_oneof = _RESPONSE.oneofs_by_name[
    "value"
]
_RESPONSE.oneofs_by_name["value"].fields.append(
    _RESPONSE.fields_by_name["load_snapshot_chunk"]
)
_RESPONSE.fields_by_name[
    "load_snapshot_chunk"
].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSE.oneofs_by_name["value"].fields.append(
    _RESPONSE.fields_by_name["apply_snapshot_chunk"]
)
_RESPONSE.fields_by_name[
    "apply_snapshot_chunk"
].containing_oneof = _RESPONSE.oneofs_by_name["value"]
_RESPONSEINITCHAIN.fields_by_name["consensus_params"].message_type = _CONSENSUSPARAMS
_RESPONSEINITCHAIN.fields_by_name["validators"].message_type = _VALIDATORUPDATE
_RESPONSEQUERY.fields_by_name[
    "proof_ops"
].message_type = tendermint_dot_crypto_dot_proof__pb2._PROOFOPS
_RESPONSEBEGINBLOCK.fields_by_name["events"].message_type = _EVENT
_RESPONSECHECKTX.fields_by_name["events"].message_type = _EVENT
_RESPONSEDELIVERTX.fields_by_name["events"].message_type = _EVENT
_RESPONSEENDBLOCK.fields_by_name["validator_updates"].message_type = _VALIDATORUPDATE
_RESPONSEENDBLOCK.fields_by_name[
    "consensus_param_updates"
].message_type = _CONSENSUSPARAMS
_RESPONSEENDBLOCK.fields_by_name["events"].message_type = _EVENT
_RESPONSELISTSNAPSHOTS.fields_by_name["snapshots"].message_type = _SNAPSHOT
_RESPONSEOFFERSNAPSHOT.fields_by_name[
    "result"
].enum_type = _RESPONSEOFFERSNAPSHOT_RESULT
_RESPONSEOFFERSNAPSHOT_RESULT.containing_type = _RESPONSEOFFERSNAPSHOT
_RESPONSEAPPLYSNAPSHOTCHUNK.fields_by_name[
    "result"
].enum_type = _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT
_RESPONSEAPPLYSNAPSHOTCHUNK_RESULT.containing_type = _RESPONSEAPPLYSNAPSHOTCHUNK
_CONSENSUSPARAMS.fields_by_name["block"].message_type = _BLOCKPARAMS
_CONSENSUSPARAMS.fields_by_name[
    "evidence"
].message_type = tendermint_dot_types_dot_params__pb2._EVIDENCEPARAMS
_CONSENSUSPARAMS.fields_by_name[
    "validator"
].message_type = tendermint_dot_types_dot_params__pb2._VALIDATORPARAMS
_CONSENSUSPARAMS.fields_by_name[
    "version"
].message_type = tendermint_dot_types_dot_params__pb2._VERSIONPARAMS
_LASTCOMMITINFO.fields_by_name["votes"].message_type = _VOTEINFO
_EVENT.fields_by_name["attributes"].message_type = _EVENTATTRIBUTE
_TXRESULT.fields_by_name["result"].message_type = _RESPONSEDELIVERTX
_VALIDATORUPDATE.fields_by_name[
    "pub_key"
].message_type = tendermint_dot_crypto_dot_keys__pb2._PUBLICKEY
_VOTEINFO.fields_by_name["validator"].message_type = _VALIDATOR
_EVIDENCE.fields_by_name["type"].enum_type = _EVIDENCETYPE
_EVIDENCE.fields_by_name["validator"].message_type = _VALIDATOR
_EVIDENCE.fields_by_name[
    "time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name["Request"] = _REQUEST
DESCRIPTOR.message_types_by_name["RequestEcho"] = _REQUESTECHO
DESCRIPTOR.message_types_by_name["RequestFlush"] = _REQUESTFLUSH
DESCRIPTOR.message_types_by_name["RequestInfo"] = _REQUESTINFO
DESCRIPTOR.message_types_by_name["RequestSetOption"] = _REQUESTSETOPTION
DESCRIPTOR.message_types_by_name["RequestInitChain"] = _REQUESTINITCHAIN
DESCRIPTOR.message_types_by_name["RequestQuery"] = _REQUESTQUERY
DESCRIPTOR.message_types_by_name["RequestBeginBlock"] = _REQUESTBEGINBLOCK
DESCRIPTOR.message_types_by_name["RequestCheckTx"] = _REQUESTCHECKTX
DESCRIPTOR.message_types_by_name["RequestDeliverTx"] = _REQUESTDELIVERTX
DESCRIPTOR.message_types_by_name["RequestEndBlock"] = _REQUESTENDBLOCK
DESCRIPTOR.message_types_by_name["RequestCommit"] = _REQUESTCOMMIT
DESCRIPTOR.message_types_by_name["RequestListSnapshots"] = _REQUESTLISTSNAPSHOTS
DESCRIPTOR.message_types_by_name["RequestOfferSnapshot"] = _REQUESTOFFERSNAPSHOT
DESCRIPTOR.message_types_by_name["RequestLoadSnapshotChunk"] = _REQUESTLOADSNAPSHOTCHUNK
DESCRIPTOR.message_types_by_name[
    "RequestApplySnapshotChunk"
] = _REQUESTAPPLYSNAPSHOTCHUNK
DESCRIPTOR.message_types_by_name["Response"] = _RESPONSE
DESCRIPTOR.message_types_by_name["ResponseException"] = _RESPONSEEXCEPTION
DESCRIPTOR.message_types_by_name["ResponseEcho"] = _RESPONSEECHO
DESCRIPTOR.message_types_by_name["ResponseFlush"] = _RESPONSEFLUSH
DESCRIPTOR.message_types_by_name["ResponseInfo"] = _RESPONSEINFO
DESCRIPTOR.message_types_by_name["ResponseSetOption"] = _RESPONSESETOPTION
DESCRIPTOR.message_types_by_name["ResponseInitChain"] = _RESPONSEINITCHAIN
DESCRIPTOR.message_types_by_name["ResponseQuery"] = _RESPONSEQUERY
DESCRIPTOR.message_types_by_name["ResponseBeginBlock"] = _RESPONSEBEGINBLOCK
DESCRIPTOR.message_types_by_name["ResponseCheckTx"] = _RESPONSECHECKTX
DESCRIPTOR.message_types_by_name["ResponseDeliverTx"] = _RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name["ResponseEndBlock"] = _RESPONSEENDBLOCK
DESCRIPTOR.message_types_by_name["ResponseCommit"] = _RESPONSECOMMIT
DESCRIPTOR.message_types_by_name["ResponseListSnapshots"] = _RESPONSELISTSNAPSHOTS
DESCRIPTOR.message_types_by_name["ResponseOfferSnapshot"] = _RESPONSEOFFERSNAPSHOT
DESCRIPTOR.message_types_by_name[
    "ResponseLoadSnapshotChunk"
] = _RESPONSELOADSNAPSHOTCHUNK
DESCRIPTOR.message_types_by_name[
    "ResponseApplySnapshotChunk"
] = _RESPONSEAPPLYSNAPSHOTCHUNK
DESCRIPTOR.message_types_by_name["ConsensusParams"] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name["BlockParams"] = _BLOCKPARAMS
DESCRIPTOR.message_types_by_name["LastCommitInfo"] = _LASTCOMMITINFO
DESCRIPTOR.message_types_by_name["Event"] = _EVENT
DESCRIPTOR.message_types_by_name["EventAttribute"] = _EVENTATTRIBUTE
DESCRIPTOR.message_types_by_name["TxResult"] = _TXRESULT
DESCRIPTOR.message_types_by_name["Validator"] = _VALIDATOR
DESCRIPTOR.message_types_by_name["ValidatorUpdate"] = _VALIDATORUPDATE
DESCRIPTOR.message_types_by_name["VoteInfo"] = _VOTEINFO
DESCRIPTOR.message_types_by_name["Evidence"] = _EVIDENCE
DESCRIPTOR.message_types_by_name["Snapshot"] = _SNAPSHOT
DESCRIPTOR.enum_types_by_name["CheckTxType"] = _CHECKTXTYPE
DESCRIPTOR.enum_types_by_name["EvidenceType"] = _EVIDENCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType(
    "Request",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUEST,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Request)
    },
)
_sym_db.RegisterMessage(Request)

RequestEcho = _reflection.GeneratedProtocolMessageType(
    "RequestEcho",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTECHO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestEcho)
    },
)
_sym_db.RegisterMessage(RequestEcho)

RequestFlush = _reflection.GeneratedProtocolMessageType(
    "RequestFlush",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTFLUSH,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestFlush)
    },
)
_sym_db.RegisterMessage(RequestFlush)

RequestInfo = _reflection.GeneratedProtocolMessageType(
    "RequestInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTINFO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestInfo)
    },
)
_sym_db.RegisterMessage(RequestInfo)

RequestSetOption = _reflection.GeneratedProtocolMessageType(
    "RequestSetOption",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTSETOPTION,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestSetOption)
    },
)
_sym_db.RegisterMessage(RequestSetOption)

RequestInitChain = _reflection.GeneratedProtocolMessageType(
    "RequestInitChain",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTINITCHAIN,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestInitChain)
    },
)
_sym_db.RegisterMessage(RequestInitChain)

RequestQuery = _reflection.GeneratedProtocolMessageType(
    "RequestQuery",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTQUERY,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestQuery)
    },
)
_sym_db.RegisterMessage(RequestQuery)

RequestBeginBlock = _reflection.GeneratedProtocolMessageType(
    "RequestBeginBlock",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTBEGINBLOCK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestBeginBlock)
    },
)
_sym_db.RegisterMessage(RequestBeginBlock)

RequestCheckTx = _reflection.GeneratedProtocolMessageType(
    "RequestCheckTx",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTCHECKTX,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestCheckTx)
    },
)
_sym_db.RegisterMessage(RequestCheckTx)

RequestDeliverTx = _reflection.GeneratedProtocolMessageType(
    "RequestDeliverTx",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTDELIVERTX,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestDeliverTx)
    },
)
_sym_db.RegisterMessage(RequestDeliverTx)

RequestEndBlock = _reflection.GeneratedProtocolMessageType(
    "RequestEndBlock",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTENDBLOCK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestEndBlock)
    },
)
_sym_db.RegisterMessage(RequestEndBlock)

RequestCommit = _reflection.GeneratedProtocolMessageType(
    "RequestCommit",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTCOMMIT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestCommit)
    },
)
_sym_db.RegisterMessage(RequestCommit)

RequestListSnapshots = _reflection.GeneratedProtocolMessageType(
    "RequestListSnapshots",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTLISTSNAPSHOTS,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestListSnapshots)
    },
)
_sym_db.RegisterMessage(RequestListSnapshots)

RequestOfferSnapshot = _reflection.GeneratedProtocolMessageType(
    "RequestOfferSnapshot",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTOFFERSNAPSHOT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestOfferSnapshot)
    },
)
_sym_db.RegisterMessage(RequestOfferSnapshot)

RequestLoadSnapshotChunk = _reflection.GeneratedProtocolMessageType(
    "RequestLoadSnapshotChunk",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTLOADSNAPSHOTCHUNK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestLoadSnapshotChunk)
    },
)
_sym_db.RegisterMessage(RequestLoadSnapshotChunk)

RequestApplySnapshotChunk = _reflection.GeneratedProtocolMessageType(
    "RequestApplySnapshotChunk",
    (_message.Message,),
    {
        "DESCRIPTOR": _REQUESTAPPLYSNAPSHOTCHUNK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.RequestApplySnapshotChunk)
    },
)
_sym_db.RegisterMessage(RequestApplySnapshotChunk)

Response = _reflection.GeneratedProtocolMessageType(
    "Response",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSE,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Response)
    },
)
_sym_db.RegisterMessage(Response)

ResponseException = _reflection.GeneratedProtocolMessageType(
    "ResponseException",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEEXCEPTION,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseException)
    },
)
_sym_db.RegisterMessage(ResponseException)

ResponseEcho = _reflection.GeneratedProtocolMessageType(
    "ResponseEcho",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEECHO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseEcho)
    },
)
_sym_db.RegisterMessage(ResponseEcho)

ResponseFlush = _reflection.GeneratedProtocolMessageType(
    "ResponseFlush",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEFLUSH,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseFlush)
    },
)
_sym_db.RegisterMessage(ResponseFlush)

ResponseInfo = _reflection.GeneratedProtocolMessageType(
    "ResponseInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEINFO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseInfo)
    },
)
_sym_db.RegisterMessage(ResponseInfo)

ResponseSetOption = _reflection.GeneratedProtocolMessageType(
    "ResponseSetOption",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSESETOPTION,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseSetOption)
    },
)
_sym_db.RegisterMessage(ResponseSetOption)

ResponseInitChain = _reflection.GeneratedProtocolMessageType(
    "ResponseInitChain",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEINITCHAIN,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseInitChain)
    },
)
_sym_db.RegisterMessage(ResponseInitChain)

ResponseQuery = _reflection.GeneratedProtocolMessageType(
    "ResponseQuery",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEQUERY,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseQuery)
    },
)
_sym_db.RegisterMessage(ResponseQuery)

ResponseBeginBlock = _reflection.GeneratedProtocolMessageType(
    "ResponseBeginBlock",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEBEGINBLOCK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseBeginBlock)
    },
)
_sym_db.RegisterMessage(ResponseBeginBlock)

ResponseCheckTx = _reflection.GeneratedProtocolMessageType(
    "ResponseCheckTx",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSECHECKTX,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseCheckTx)
    },
)
_sym_db.RegisterMessage(ResponseCheckTx)

ResponseDeliverTx = _reflection.GeneratedProtocolMessageType(
    "ResponseDeliverTx",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEDELIVERTX,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseDeliverTx)
    },
)
_sym_db.RegisterMessage(ResponseDeliverTx)

ResponseEndBlock = _reflection.GeneratedProtocolMessageType(
    "ResponseEndBlock",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEENDBLOCK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseEndBlock)
    },
)
_sym_db.RegisterMessage(ResponseEndBlock)

ResponseCommit = _reflection.GeneratedProtocolMessageType(
    "ResponseCommit",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSECOMMIT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseCommit)
    },
)
_sym_db.RegisterMessage(ResponseCommit)

ResponseListSnapshots = _reflection.GeneratedProtocolMessageType(
    "ResponseListSnapshots",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSELISTSNAPSHOTS,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseListSnapshots)
    },
)
_sym_db.RegisterMessage(ResponseListSnapshots)

ResponseOfferSnapshot = _reflection.GeneratedProtocolMessageType(
    "ResponseOfferSnapshot",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEOFFERSNAPSHOT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseOfferSnapshot)
    },
)
_sym_db.RegisterMessage(ResponseOfferSnapshot)

ResponseLoadSnapshotChunk = _reflection.GeneratedProtocolMessageType(
    "ResponseLoadSnapshotChunk",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSELOADSNAPSHOTCHUNK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseLoadSnapshotChunk)
    },
)
_sym_db.RegisterMessage(ResponseLoadSnapshotChunk)

ResponseApplySnapshotChunk = _reflection.GeneratedProtocolMessageType(
    "ResponseApplySnapshotChunk",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESPONSEAPPLYSNAPSHOTCHUNK,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ResponseApplySnapshotChunk)
    },
)
_sym_db.RegisterMessage(ResponseApplySnapshotChunk)

ConsensusParams = _reflection.GeneratedProtocolMessageType(
    "ConsensusParams",
    (_message.Message,),
    {
        "DESCRIPTOR": _CONSENSUSPARAMS,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ConsensusParams)
    },
)
_sym_db.RegisterMessage(ConsensusParams)

BlockParams = _reflection.GeneratedProtocolMessageType(
    "BlockParams",
    (_message.Message,),
    {
        "DESCRIPTOR": _BLOCKPARAMS,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.BlockParams)
    },
)
_sym_db.RegisterMessage(BlockParams)

LastCommitInfo = _reflection.GeneratedProtocolMessageType(
    "LastCommitInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _LASTCOMMITINFO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.LastCommitInfo)
    },
)
_sym_db.RegisterMessage(LastCommitInfo)

Event = _reflection.GeneratedProtocolMessageType(
    "Event",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVENT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Event)
    },
)
_sym_db.RegisterMessage(Event)

EventAttribute = _reflection.GeneratedProtocolMessageType(
    "EventAttribute",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVENTATTRIBUTE,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.EventAttribute)
    },
)
_sym_db.RegisterMessage(EventAttribute)

TxResult = _reflection.GeneratedProtocolMessageType(
    "TxResult",
    (_message.Message,),
    {
        "DESCRIPTOR": _TXRESULT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.TxResult)
    },
)
_sym_db.RegisterMessage(TxResult)

Validator = _reflection.GeneratedProtocolMessageType(
    "Validator",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATOR,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Validator)
    },
)
_sym_db.RegisterMessage(Validator)

ValidatorUpdate = _reflection.GeneratedProtocolMessageType(
    "ValidatorUpdate",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATORUPDATE,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.ValidatorUpdate)
    },
)
_sym_db.RegisterMessage(ValidatorUpdate)

VoteInfo = _reflection.GeneratedProtocolMessageType(
    "VoteInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _VOTEINFO,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.VoteInfo)
    },
)
_sym_db.RegisterMessage(VoteInfo)

Evidence = _reflection.GeneratedProtocolMessageType(
    "Evidence",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVIDENCE,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Evidence)
    },
)
_sym_db.RegisterMessage(Evidence)

Snapshot = _reflection.GeneratedProtocolMessageType(
    "Snapshot",
    (_message.Message,),
    {
        "DESCRIPTOR": _SNAPSHOT,
        "__module__": "tendermint.abci.types_pb2"
        # @@protoc_insertion_point(class_scope:tendermint.abci.Snapshot)
    },
)
_sym_db.RegisterMessage(Snapshot)


DESCRIPTOR._options = None
_CHECKTXTYPE.values_by_name["NEW"]._options = None
_CHECKTXTYPE.values_by_name["RECHECK"]._options = None
_REQUESTINITCHAIN.fields_by_name["time"]._options = None
_REQUESTINITCHAIN.fields_by_name["validators"]._options = None
_REQUESTBEGINBLOCK.fields_by_name["header"]._options = None
_REQUESTBEGINBLOCK.fields_by_name["last_commit_info"]._options = None
_REQUESTBEGINBLOCK.fields_by_name["byzantine_validators"]._options = None
_RESPONSEINITCHAIN.fields_by_name["validators"]._options = None
_RESPONSEBEGINBLOCK.fields_by_name["events"]._options = None
_RESPONSECHECKTX.fields_by_name["events"]._options = None
_RESPONSEDELIVERTX.fields_by_name["events"]._options = None
_RESPONSEENDBLOCK.fields_by_name["validator_updates"]._options = None
_RESPONSEENDBLOCK.fields_by_name["events"]._options = None
_LASTCOMMITINFO.fields_by_name["votes"]._options = None
_EVENT.fields_by_name["attributes"]._options = None
_TXRESULT.fields_by_name["result"]._options = None
_VALIDATORUPDATE.fields_by_name["pub_key"]._options = None
_VOTEINFO.fields_by_name["validator"]._options = None
_EVIDENCE.fields_by_name["validator"]._options = None
_EVIDENCE.fields_by_name["time"]._options = None

_ABCIAPPLICATION = _descriptor.ServiceDescriptor(
    name="ABCIApplication",
    full_name="tendermint.abci.ABCIApplication",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=6448,
    serialized_end=7731,
    methods=[
        _descriptor.MethodDescriptor(
            name="Echo",
            full_name="tendermint.abci.ABCIApplication.Echo",
            index=0,
            containing_service=None,
            input_type=_REQUESTECHO,
            output_type=_RESPONSEECHO,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Flush",
            full_name="tendermint.abci.ABCIApplication.Flush",
            index=1,
            containing_service=None,
            input_type=_REQUESTFLUSH,
            output_type=_RESPONSEFLUSH,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Info",
            full_name="tendermint.abci.ABCIApplication.Info",
            index=2,
            containing_service=None,
            input_type=_REQUESTINFO,
            output_type=_RESPONSEINFO,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="SetOption",
            full_name="tendermint.abci.ABCIApplication.SetOption",
            index=3,
            containing_service=None,
            input_type=_REQUESTSETOPTION,
            output_type=_RESPONSESETOPTION,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeliverTx",
            full_name="tendermint.abci.ABCIApplication.DeliverTx",
            index=4,
            containing_service=None,
            input_type=_REQUESTDELIVERTX,
            output_type=_RESPONSEDELIVERTX,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CheckTx",
            full_name="tendermint.abci.ABCIApplication.CheckTx",
            index=5,
            containing_service=None,
            input_type=_REQUESTCHECKTX,
            output_type=_RESPONSECHECKTX,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Query",
            full_name="tendermint.abci.ABCIApplication.Query",
            index=6,
            containing_service=None,
            input_type=_REQUESTQUERY,
            output_type=_RESPONSEQUERY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Commit",
            full_name="tendermint.abci.ABCIApplication.Commit",
            index=7,
            containing_service=None,
            input_type=_REQUESTCOMMIT,
            output_type=_RESPONSECOMMIT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="InitChain",
            full_name="tendermint.abci.ABCIApplication.InitChain",
            index=8,
            containing_service=None,
            input_type=_REQUESTINITCHAIN,
            output_type=_RESPONSEINITCHAIN,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BeginBlock",
            full_name="tendermint.abci.ABCIApplication.BeginBlock",
            index=9,
            containing_service=None,
            input_type=_REQUESTBEGINBLOCK,
            output_type=_RESPONSEBEGINBLOCK,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="EndBlock",
            full_name="tendermint.abci.ABCIApplication.EndBlock",
            index=10,
            containing_service=None,
            input_type=_REQUESTENDBLOCK,
            output_type=_RESPONSEENDBLOCK,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListSnapshots",
            full_name="tendermint.abci.ABCIApplication.ListSnapshots",
            index=11,
            containing_service=None,
            input_type=_REQUESTLISTSNAPSHOTS,
            output_type=_RESPONSELISTSNAPSHOTS,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="OfferSnapshot",
            full_name="tendermint.abci.ABCIApplication.OfferSnapshot",
            index=12,
            containing_service=None,
            input_type=_REQUESTOFFERSNAPSHOT,
            output_type=_RESPONSEOFFERSNAPSHOT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="LoadSnapshotChunk",
            full_name="tendermint.abci.ABCIApplication.LoadSnapshotChunk",
            index=13,
            containing_service=None,
            input_type=_REQUESTLOADSNAPSHOTCHUNK,
            output_type=_RESPONSELOADSNAPSHOTCHUNK,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ApplySnapshotChunk",
            full_name="tendermint.abci.ABCIApplication.ApplySnapshotChunk",
            index=14,
            containing_service=None,
            input_type=_REQUESTAPPLYSNAPSHOTCHUNK,
            output_type=_RESPONSEAPPLYSNAPSHOTCHUNK,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_ABCIAPPLICATION)

DESCRIPTOR.services_by_name["ABCIApplication"] = _ABCIAPPLICATION

# @@protoc_insertion_point(module_scope)
